@@ -71,6 +71,11 @@ from diff_diff.prep import (
     balance_panel,
     create_event_time,
     generate_did_data,
+    generate_ddd_data,
+    generate_event_study_data,
+    generate_factor_data,
+    generate_panel_data,
+    generate_staggered_data,
     make_post_indicator,
     make_treatment_indicator,
     rank_control_units,
@@ -131,7 +136,7 @@ from diff_diff.datasets import (
     load_mpdta,
 )
 
-__version__ = "2.1.1"
+__version__ = "2.1.2"
 __all__ = [
     # Estimators
     "DifferenceInDifferences",
@@ -190,6 +195,11 @@ __all__ = [
     "validate_did_data",
     "summarize_did_data",
     "generate_did_data",
+    "generate_staggered_data",
+    "generate_factor_data",
+    "generate_ddd_data",
+    "generate_panel_data",
+    "generate_event_study_data",
     "create_event_time",
     "aggregate_to_cohorts",
     "rank_control_units",
